==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebFilteringOperandDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringOperationDescriptionMetadata } from "./WebFilteringOperationDescriptionMetadata";
import { WebFilteringOperandDescription } from "./WebFilteringOperandDescription";
/**
 * @hidden
 */
var WebFilteringOperandDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebFilteringOperandDescriptionMetadata, _super);
    function WebFilteringOperandDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebFilteringOperandDescriptionMetadata.b = function (a) {
        if (WebFilteringOperandDescriptionMetadata.a == null) {
            WebFilteringOperandDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebFilteringOperandDescriptionMetadata.c(WebFilteringOperandDescriptionMetadata.a);
        }
        if (a.j(WebFilteringOperandDescriptionMetadata.a)) {
            return;
        }
        a.y(WebFilteringOperandDescriptionMetadata.a);
        WebFilteringOperationDescriptionMetadata.d(a);
    };
    WebFilteringOperandDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:FilteringOperand");
        a.item("__packageNameWC", "String:grids");
        a.item("Operations", "Array:WebFilteringOperationDescription:FilteringOperation");
    };
    WebFilteringOperandDescriptionMetadata.d = function (a) {
        WebFilteringOperandDescriptionMetadata.b(a);
        a.aa("WebFilteringOperand", function () { return new WebFilteringOperandDescription(); });
        a.z("WebFilteringOperand", WebFilteringOperandDescriptionMetadata.a);
    };
    WebFilteringOperandDescriptionMetadata.$t = markType(WebFilteringOperandDescriptionMetadata, 'WebFilteringOperandDescriptionMetadata');
    WebFilteringOperandDescriptionMetadata.a = null;
    return WebFilteringOperandDescriptionMetadata;
}(Base));
export { WebFilteringOperandDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebFilteringOperandDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringOperationDescriptionMetadata } from "./WebFilteringOperationDescriptionMetadata";
import { WebFilteringOperandDescription } from "./WebFilteringOperandDescription";
/**
 * @hidden
 */
var WebFilteringOperandDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebFilteringOperandDescriptionMetadata, _super);
    function WebFilteringOperandDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebFilteringOperandDescriptionMetadata.b = function (a) {
        if (WebFilteringOperandDescriptionMetadata.a == null) {
            WebFilteringOperandDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebFilteringOperandDescriptionMetadata.c(WebFilteringOperandDescriptionMetadata.a);
        }
        if (a.k(WebFilteringOperandDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebFilteringOperandDescriptionMetadata.a);
        WebFilteringOperationDescriptionMetadata.d(a);
    };
    WebFilteringOperandDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:FilteringOperand");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__skipSuffix", "Boolean");
        a.item("Operations", "Array:WebFilteringOperationDescription:FilteringOperation");
    };
    WebFilteringOperandDescriptionMetadata.d = function (a) {
        WebFilteringOperandDescriptionMetadata.b(a);
        a.ac("WebFilteringOperand", function () { return new WebFilteringOperandDescription(); });
        a.ab("WebFilteringOperand", WebFilteringOperandDescriptionMetadata.a);
    };
    WebFilteringOperandDescriptionMetadata.$t = markType(WebFilteringOperandDescriptionMetadata, 'WebFilteringOperandDescriptionMetadata');
    WebFilteringOperandDescriptionMetadata.a = null;
    return WebFilteringOperandDescriptionMetadata;
}(Base));
export { WebFilteringOperandDescriptionMetadata };
